@@ -131,8 +131,9 @@ oobs_object_init (OobsObject *object)
   priv = OOBS_OBJECT_GET_PRIVATE (object);
   priv->session = NULL;
   priv->remote_object = NULL;
-
   dbus_error_init (&priv->dbus_error);
+
+  object->_priv = priv;
 }
 
 static void
@@ -144,7 +145,7 @@ oobs_object_finalize (GObject *object)
   g_return_if_fail (OOBS_IS_OBJECT (object));
 
   obj  = OOBS_OBJECT (object);
-  priv = OOBS_OBJECT_GET_PRIVATE (obj);
+  priv = OOBS_OBJECT (object)->_priv;
 
   if (priv)
     {
@@ -168,7 +169,7 @@ changed_signal_filter (DBusConnection *connection,
   OobsObjectPrivate *priv;
 
   object = OOBS_OBJECT (user_data);
-  priv   = OOBS_OBJECT_GET_PRIVATE (object);
+  priv   = OOBS_OBJECT (object)->_priv;
 
   if (dbus_message_is_signal (message, priv->method, "changed") &&
       dbus_message_has_path (message, priv->path))
@@ -187,7 +188,7 @@ connect_object_to_session (OobsObject *object)
   DBusConnection    *connection;
   gchar             *rule;
 
-  priv = OOBS_OBJECT_GET_PRIVATE (object);
+  priv = OOBS_OBJECT (object)->_priv;
   connection = _oobs_session_get_connection_bus (priv->session);
 
   _oobs_session_register_object (priv->session, object);
@@ -218,7 +219,7 @@ oobs_object_set_property (GObject      *object,
   g_return_if_fail (OOBS_IS_OBJECT (object));
 
   obj  = OOBS_OBJECT (object);
-  priv = OOBS_OBJECT_GET_PRIVATE (obj);
+  priv = obj->_priv;
 
   switch (prop_id)
     {
@@ -251,7 +252,7 @@ oobs_object_get_property (GObject      *object,
   g_return_if_fail (OOBS_IS_OBJECT (object));
 
   obj  = OOBS_OBJECT (object);
-  priv = OOBS_OBJECT_GET_PRIVATE (obj);
+  priv = obj->_priv;
 
   switch (prop_id)
     {
@@ -274,7 +275,7 @@ _oobs_object_set_dbus_message (OobsObject *object, DBusMessage *message)
 			   message, (GDestroyNotify) dbus_message_unref);
 }
 
-static OobsObjectResult
+static OobsResult
 update_object_from_message (OobsObject  *object,
 			    DBusMessage *message)
 {
@@ -285,24 +286,26 @@ update_object_from_message (OobsObject  *object,
   if (!class->update)
     {
       g_critical ("There is no update() implementation for this object");
-      return OOBS_OBJECT_RESULT_MALFORMED;
+      return OOBS_RESULT_MALFORMED_DATA;
     }
 
   g_object_set_qdata (G_OBJECT (object), dbus_connection_quark, message);
   class->update (object);
   g_object_steal_qdata (G_OBJECT (object), dbus_connection_quark);
 
-  return OOBS_OBJECT_RESULT_OK;
+  return OOBS_RESULT_OK;
 }
 
 static DBusMessage*
-run_message (OobsObject *object, DBusMessage *message)
+run_message (OobsObject  *object,
+	     DBusMessage *message,
+	     OobsResult  *result)
 {
   OobsObjectPrivate *priv;
   DBusConnection    *connection;
   DBusMessage       *reply;
 
-  priv = OOBS_OBJECT_GET_PRIVATE (object);
+  priv = object->_priv;
   connection = _oobs_session_get_connection_bus (priv->session);
 
   g_return_val_if_fail (connection != NULL, NULL);
@@ -311,11 +314,16 @@ run_message (OobsObject *object, DBusMessage *message)
 
   if (dbus_error_is_set (&priv->dbus_error))
     {
-      g_critical ("There was an error communicating with the backends: %s", priv->dbus_error.message);
+      if (dbus_error_has_name (&priv->dbus_error, DBUS_ERROR_ACCESS_DENIED))
+	*result = OOBS_RESULT_ACCESS_DENIED;
+      else
+	g_critical ("There was an unknown error communicating with the backends: %s", priv->dbus_error.message);
+
       dbus_error_free (&priv->dbus_error);
       return NULL;
     }
 
+  *result = OOBS_RESULT_OK;
   return reply;
 }
 
@@ -323,7 +331,7 @@ static void
 async_message_cb (DBusPendingCall *pending_call, gpointer data)
 {
   OobsObjectAsyncCallbackData *async_data;
-  OobsObjectResult result = OOBS_OBJECT_RESULT_MALFORMED;
+  OobsResult result = OOBS_RESULT_MALFORMED_DATA;
   DBusMessage *reply;
   DBusError error;
 
@@ -333,15 +341,22 @@ async_message_cb (DBusPendingCall *pending_call, gpointer data)
 
   if (dbus_set_error_from_message (&error, reply))
     {
-      /* FIXME: process error */
-      result = OOBS_OBJECT_RESULT_MALFORMED;
+      if (dbus_error_has_name (&error, DBUS_ERROR_ACCESS_DENIED))
+	result = OOBS_RESULT_ACCESS_DENIED;
+      else
+	{
+	  /* FIXME: process error */
+	  result = OOBS_RESULT_MALFORMED_DATA;
+	}
+
+      dbus_error_free (&error);
     }
   else
     {
       if (async_data->update)
 	result = update_object_from_message (OOBS_OBJECT (async_data->object), reply);
       else
-	result = OOBS_OBJECT_RESULT_OK;
+	result = OOBS_RESULT_OK;
     }
 
   if (async_data->func)
@@ -363,7 +378,7 @@ run_message_async (OobsObject          *object,
   OobsObjectAsyncCallbackData *async_data;
   DBusConnection *connection;
 
-  priv = OOBS_OBJECT_GET_PRIVATE (object);
+  priv = object->_priv;
   connection = _oobs_session_get_connection_bus (priv->session);
   dbus_connection_send_with_reply (connection, message, &call, -1);
 
@@ -383,7 +398,7 @@ get_commit_message (OobsObject *object)
   OobsObjectPrivate *priv;
   DBusMessage       *message;
 
-  priv  = OOBS_OBJECT_GET_PRIVATE (object);
+  priv  = object->_priv;
   class = OOBS_OBJECT_GET_CLASS (object);
 
   if (!priv->session)
@@ -421,7 +436,7 @@ get_update_message (OobsObject *object)
 {
   OobsObjectPrivate *priv;
 
-  priv = OOBS_OBJECT_GET_PRIVATE (object);
+  priv = object->_priv;
 
   if (!priv->session)
     {
@@ -440,25 +455,25 @@ get_update_message (OobsObject *object)
  * Commits to the system all the changes done
  * to the configuration held by an #OobsObject.
  *
- * Return value: an #OobsObjectResult enum with the error code.
+ * Return value: an #OobsResult enum with the error code.
  **/
-OobsObjectResult
+OobsResult
 oobs_object_commit (OobsObject *object)
 {
   DBusMessage *message;
+  OobsResult result;
 
-  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_OBJECT_RESULT_MALFORMED);
+  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_RESULT_MALFORMED_DATA);
 
   message = get_commit_message (object);
 
   if (!message)
-    return OOBS_OBJECT_RESULT_MALFORMED;
+    return OOBS_RESULT_MALFORMED_DATA;
 
-  run_message (object, message);
+  run_message (object, message, &result);
   dbus_message_unref (message);
 
-  /* FIXME */
-  return OOBS_OBJECT_RESULT_OK;
+  return result;
 }
 
 /**
@@ -470,27 +485,27 @@ oobs_object_commit (OobsObject *object)
  * Commits to the system all the changes done to the configuration held by an #OobsObject.
  * This change will be asynchronous, being run the function @func when the change has been done.
  * 
- * Return value: an #OobsObjectResult enum with the error code. Due to the asynchronous nature
- * of the function, only OOBS_OBJECT_RESULT_MALFORMED and OOBS_OBJECT_RESULT_OK can be returned.
+ * Return value: an #OobsResult enum with the error code. Due to the asynchronous nature
+ * of the function, only OOBS_RESULT_MALFORMED and OOBS_RESULT_OK can be returned.
  **/
-OobsObjectResult
+OobsResult
 oobs_object_commit_async (OobsObject          *object,
 			  OobsObjectAsyncFunc  func,
 			  gpointer             data)
 {
   DBusMessage *message;
 
-  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_OBJECT_RESULT_MALFORMED);
+  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_RESULT_MALFORMED_DATA);
 
   message = get_commit_message (object);
 
   if (!message)
-    return OOBS_OBJECT_RESULT_MALFORMED;
+    return OOBS_RESULT_MALFORMED_DATA;
 
   run_message_async (object, message, FALSE, func, data);
   dbus_message_unref (message);
 
-  return OOBS_OBJECT_RESULT_OK;
+  return OOBS_RESULT_OK;
 }
 
 /**
@@ -501,22 +516,22 @@ oobs_object_commit_async (OobsObject          *object,
  * with the actual system configuration. All the changes done
  * to the configuration held by the #OobsObject will be forgotten.
  *
- * Return value: an #OobsObjectResult enum with the error code.
+ * Return value: an #OobsResult enum with the error code.
  **/
-OobsObjectResult
+OobsResult
 oobs_object_update (OobsObject *object)
 {
   DBusMessage *message, *reply;
-  OobsObjectResult result = OOBS_OBJECT_RESULT_MALFORMED;
+  OobsResult result = OOBS_RESULT_MALFORMED_DATA;
 
-  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_OBJECT_RESULT_MALFORMED);
+  g_return_val_if_fail (OOBS_IS_OBJECT (object), OOBS_RESULT_MALFORMED_DATA);
 
   message = get_update_message (object);
 
   if (!message)
-    return OOBS_OBJECT_RESULT_MALFORMED;
+    return OOBS_RESULT_MALFORMED_DATA;
 
-  reply = run_message (object, message);
+  reply = run_message (object, message, &result);
 
   if (reply)
     {
@@ -540,10 +555,10 @@ oobs_object_update (OobsObject *object)
  * The update operation will be asynchronous, being run the
  * function @func when the update has been done.
  * 
- * Return value: an #OobsObjectResult enum with the error code. Due to the asynchronous nature
- * of the function, only OOBS_OBJECT_RESULT_MALFORMED and OOBS_OBJECT_RESULT_OK can be returned.
+ * Return value: an #OobsResult enum with the error code. Due to the asynchronous nature
+ * of the function, only OOBS_RESULT_MALFORMED and OOBS_RESULT_OK can be returned.
  **/
-OobsObjectResult
+OobsResult
 oobs_object_update_async (OobsObject          *object,
 			  OobsObjectAsyncFunc  func,
 			  gpointer             data)
@@ -553,10 +568,10 @@ oobs_object_update_async (OobsObject          *object,
   message = get_update_message (object);
 
   if (!message)
-    return OOBS_OBJECT_RESULT_MALFORMED;
+    return OOBS_RESULT_MALFORMED_DATA;
 
   run_message_async (object, message, TRUE, func, data);
   dbus_message_unref (message);
 
-  return OOBS_OBJECT_RESULT_OK;
+  return OOBS_RESULT_OK;
 }
