@@ -76,6 +76,7 @@ oobs_services_config_init (OobsServicesConfig *config)
   priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (config);
 
   priv->services_list = _oobs_list_new (OOBS_TYPE_SERVICE);
+  config->_priv = priv;
 }
 
 static void
@@ -92,7 +93,7 @@ oobs_services_config_finalize (GObject *object)
 
   g_return_if_fail (OOBS_IS_SERVICES_CONFIG (object));
 
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (object);
+  priv = OOBS_SERVICES_CONFIG (object)->_priv;
 
   if (priv)
     {
@@ -135,7 +136,7 @@ create_runlevels_list_from_dbus_reply (OobsObject      *object,
   OobsServicesRunlevel *runlevel;
   gchar *name;
 
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (object);
+  priv = OOBS_SERVICES_CONFIG (object)->_priv;
 
   while (dbus_message_iter_get_arg_type (&iter) == DBUS_TYPE_STRING)
     {
@@ -160,7 +161,7 @@ get_runlevel (OobsServicesConfig *config,
   OobsServicesRunlevel *rl;
   GList *list;
 
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (config);
+  priv = config->_priv;
   list = priv->runlevels;
 
   while (list)
@@ -185,7 +186,7 @@ create_service_runlevels_from_dbus_reply (OobsServicesConfig *config,
   DBusMessageIter runlevel_iter;
   OobsServicesRunlevel *rl;
   OobsServiceStatus status;
-  gchar *runlevel, *start;
+  gchar *runlevel;
   gint priority;
 
   while (dbus_message_iter_get_arg_type (&struct_iter) == DBUS_TYPE_STRUCT)
@@ -195,7 +196,7 @@ create_service_runlevels_from_dbus_reply (OobsServicesConfig *config,
       dbus_message_iter_get_basic (&runlevel_iter, &runlevel);
       dbus_message_iter_next (&runlevel_iter);
 
-      dbus_message_iter_get_basic (&runlevel_iter, &start);
+      dbus_message_iter_get_basic (&runlevel_iter, &status);
       dbus_message_iter_next (&runlevel_iter);
 
       dbus_message_iter_get_basic (&runlevel_iter, &priority);
@@ -204,10 +205,7 @@ create_service_runlevels_from_dbus_reply (OobsServicesConfig *config,
       rl = get_runlevel (config, runlevel);
 
       if (rl)
-	{
-	  status = (strcmp (start, "start") == 0) ? OOBS_SERVICE_START : OOBS_SERVICE_STOP;
-	  oobs_service_set_runlevel_configuration (service, rl, status, priority);
-	}
+	oobs_service_set_runlevel_configuration (service, rl, status, priority);
 
       dbus_message_iter_next (&struct_iter);
     }
@@ -248,7 +246,7 @@ oobs_services_config_update (OobsObject *object)
   OobsService     *service;
   gchar           *default_runlevel;
 
-  priv  = OOBS_SERVICES_CONFIG_GET_PRIVATE (object);
+  priv  = OOBS_SERVICES_CONFIG (object)->_priv;
   reply = _oobs_object_get_dbus_message (object);
 
   _oobs_list_set_locked (priv->services_list, FALSE);
@@ -291,13 +289,14 @@ create_dbus_struct_from_service_runlevels (OobsService     *service,
 {
   DBusMessageIter runlevels_iter, struct_iter;
   OobsServicesRunlevel *runlevel;
-  gint status, priority;
+  OobsServiceStatus status;
+  gint priority;
 
   dbus_message_iter_open_container (iter,
 				    DBUS_TYPE_ARRAY,
 				    DBUS_STRUCT_BEGIN_CHAR_AS_STRING
 				    DBUS_TYPE_STRING_AS_STRING
-				    DBUS_TYPE_STRING_AS_STRING
+				    DBUS_TYPE_INT32_AS_STRING
 				    DBUS_TYPE_INT32_AS_STRING
 				    DBUS_STRUCT_END_CHAR_AS_STRING,
 				    &runlevels_iter);
@@ -315,7 +314,7 @@ create_dbus_struct_from_service_runlevels (OobsService     *service,
       dbus_message_iter_open_container (&runlevels_iter, DBUS_TYPE_STRUCT, NULL, &struct_iter);
 
       utils_append_string (&struct_iter, runlevel->name);
-      utils_append_string (&struct_iter, (status == OOBS_SERVICE_START) ? "start" : "stop");
+      dbus_message_iter_append_basic (&struct_iter, DBUS_TYPE_INT32, &status);
       dbus_message_iter_append_basic (&struct_iter, DBUS_TYPE_INT32, &priority);
 
       dbus_message_iter_close_container (&runlevels_iter, &struct_iter);
@@ -342,8 +341,6 @@ create_dbus_struct_from_service (OobsService     *service,
   dbus_message_iter_open_container (array_iter, DBUS_TYPE_STRUCT, NULL, &struct_iter);
 
   utils_append_string (&struct_iter, name);
-  /* FIXME: no role */
-  utils_append_string (&struct_iter, NULL);
   create_dbus_struct_from_service_runlevels (service, runlevels, message, &struct_iter);
 
   dbus_message_iter_close_container (array_iter, &struct_iter);
@@ -364,19 +361,12 @@ oobs_services_config_commit (OobsObject *object)
   GObject *service;
 
   correct = TRUE;
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (object);
+  priv = OOBS_SERVICES_CONFIG (object)->_priv;
   message = _oobs_object_get_dbus_message (object);
-
   dbus_message_iter_init_append (message, &iter);
-  dbus_message_iter_open_container (&iter,
-				    DBUS_TYPE_ARRAY,
-				    DBUS_STRUCT_BEGIN_CHAR_AS_STRING
-				    DBUS_TYPE_STRING_AS_STRING
-				    DBUS_TYPE_STRING_AS_STRING
-				    DBUS_STRUCT_END_CHAR_AS_STRING,
-				    &array_iter);
+
   /* FIXME: nothing inserted here, backends ignore this */
-  dbus_message_iter_close_container (&iter, &array_iter);
+  utils_create_dbus_array_from_string_list (NULL, message, &iter);
 
   /* FIXME: this is ignored by the backend too */
   utils_append_string (&iter, NULL);
@@ -385,11 +375,10 @@ oobs_services_config_commit (OobsObject *object)
 				    DBUS_TYPE_ARRAY,
 				    DBUS_STRUCT_BEGIN_CHAR_AS_STRING
 				    DBUS_TYPE_STRING_AS_STRING
-				    DBUS_TYPE_STRING_AS_STRING
 				    DBUS_TYPE_ARRAY_AS_STRING
 				    DBUS_STRUCT_BEGIN_CHAR_AS_STRING
 				    DBUS_TYPE_STRING_AS_STRING
-				    DBUS_TYPE_STRING_AS_STRING
+				    DBUS_TYPE_INT32_AS_STRING
 				    DBUS_TYPE_INT32_AS_STRING
 				    DBUS_STRUCT_END_CHAR_AS_STRING
 				    DBUS_STRUCT_END_CHAR_AS_STRING,
@@ -464,7 +453,7 @@ oobs_services_config_get_services (OobsServicesConfig *config)
   g_return_val_if_fail (config != NULL, NULL);
   g_return_val_if_fail (OOBS_IS_SERVICES_CONFIG (config), NULL);
 
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (config);
+  priv = config->_priv;
 
   return priv->services_list;
 }
@@ -476,7 +465,7 @@ oobs_services_config_get_runlevels (OobsServicesConfig *config)
 
   g_return_val_if_fail (OOBS_IS_SERVICES_CONFIG (config), NULL);
   
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (config);
+  priv = config->_priv;
 
   return g_list_copy (priv->runlevels);
 }
@@ -488,7 +477,7 @@ oobs_services_config_get_default_runlevel (OobsServicesConfig *config)
 
   g_return_val_if_fail (OOBS_IS_SERVICES_CONFIG (config), NULL);
   
-  priv = OOBS_SERVICES_CONFIG_GET_PRIVATE (config);
+  priv = config->_priv;
 
   return priv->default_runlevel;
 }
