@@ -24,6 +24,7 @@
 G_BEGIN_DECLS
 
 #include <glib-object.h>
+#include "oobs-result.h"
 
 #define OOBS_TYPE_SESSION         (oobs_session_get_type ())
 #define OOBS_SESSION(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), OOBS_TYPE_SESSION, OobsSession))
@@ -47,23 +48,30 @@ typedef struct _OobsSessionClass OobsSessionClass;
 struct _OobsSession
 {
   GObject parent;
+
+  /*<private>*/
+  gpointer _priv;
 };
 
 struct _OobsSessionClass
 {
   GObjectClass parent_class;
+
+  void (*_oobs_padding1) (void);
+  void (*_oobs_padding2) (void);
 };
 
 GType        oobs_session_get_type (void);
 
 OobsSession *oobs_session_get      (void);
-void         oobs_session_commit   (OobsSession *session);
+OobsResult   oobs_session_commit   (OobsSession *session);
 
-GList*       oobs_session_get_supported_platforms (OobsSession *session);
-
-G_CONST_RETURN gchar *oobs_session_get_platform (OobsSession *session);
-void                  oobs_session_set_platform (OobsSession *session,
-						 const gchar *platform);
+OobsResult   oobs_session_get_supported_platforms (OobsSession  *session,
+						   GList       **platforms);
+OobsResult   oobs_session_get_platform            (OobsSession  *session,
+						   gchar       **platform);
+OobsResult   oobs_session_set_platform            (OobsSession  *session,
+						   const gchar  *platform);
 
 G_END_DECLS
 
